@@ -23,7 +23,7 @@ except:
 try:
     from osgeo import gdal
 except:
-    raise ModuleNotFoundError('You have to install gdal first with this command "conda install -c conda-forge gdal"')
+    raise ModuleNotFoundError('1.You have to install gdal first with this command "conda install -c conda-forge gdal" 2.pip install lazyearth again')
 
 class objearth():
     def __init__(self):
@@ -32,8 +32,8 @@ class objearth():
     def montage(img1,img2):
         """
         compare 2 image.
-        :param img1: first array
-        :param img2: second array
+        :param img1 : first array
+        :param img2 : second array
         """
         plt.figure(figsize=(15,15))
         plt.subplot(121),plt.imshow(img1, cmap = 'gray')
@@ -46,11 +46,11 @@ class objearth():
     def falsecolor(Dataset1,Dataset2,Dataset3,bright=10):
         """
         combination 3 bands which any bands (Used with Xarray)
-        :param Dataset1: band 1
-        :param Dataset1: band 2
-        :param Dataset3: band 3
-        :param bright: brightness of image
-        :return :The stacked array 
+        :param Dataset1 : band 1
+        :param Dataset1 : band 2
+        :param Dataset3 : band 3
+        :param bright   : brightness of image
+        :return         : The stacked array 
         """
         BAND1    = xarray.where(Dataset1==-9999,numpy.nan,Dataset1)
         band1    = BAND1.to_numpy()/10000*bright
@@ -65,9 +65,9 @@ class objearth():
     def truecolor(Dataset,bright=10):
         """
         combination 3 bands which Red Green Blue bands (Used with Xarray)
-        :param Dataset: Dataset of satellite bands
-        :param bright: brightness of image
-        :return : RGB array stacked 
+        :param Dataset : Dataset of satellite bands
+        :param bright  : brightness of image
+        :return        : RGB array stacked 
         """
         RED    = xarray.where(Dataset.red==-9999,numpy.nan,Dataset.red)
         red    = RED.to_numpy()/10000*bright
@@ -82,10 +82,10 @@ class objearth():
     def bandcombination(RED,GREEN,BLUE,bright=10):
         """
         combination 2 bands which Red,Green,Blue bands (Used with .tif file)
-        :param Red: Red bands
-        :param Green: Green bands
-        :param Blue: Blue bands
-        :return : RGB array stacked 
+        :param Red   : Red bands
+        :param Green : Green bands
+        :param Blue  : Blue bands
+        :return      : RGB array stacked 
         """
         red    = RED/10000   *bright
         green  = GREEN/10000 *bright
@@ -96,9 +96,9 @@ class objearth():
     def clearcloud(self,Dataset0,Dataset1):
         '''
         Clear the clouds
-        :param Dataset0: The image that want to clear cloud.
-        :param Dataset1: The better image that used to maske the first image better.
-        :return : better cloud image
+        :param Dataset0 : The image that want to clear cloud.
+        :param Dataset1 : The better image that used to maske the first image better.
+        :return         : better cloud image
         '''
         self.Dataset0 = Dataset0
         self.Dataset1 = Dataset1
@@ -120,7 +120,14 @@ class objearth():
     def plotshow(DataArray,cmap=True,area=True,zenmode=False,figsize=(8,8),xlabel="x axis size",ylabel="y axis size",title=''):
         '''
         Plot image 
-        :param DataArray: Numpy array/Xarray data array
+        :param DataArray : Numpy array/Xarray data array
+        :param area      : area that you want [y-up,y-dwon,x-left,x-right]
+        :param figsize   : size of image
+        :param camp      : colormap
+        :param zonmode   : plotshow only image no any detail
+        :param xlabel    : x-axis label
+        :param ylabel    : y-axis label
+        :param title     : title label
         '''
         if type(DataArray) == xarray.core.dataarray.DataArray:
             if area==True:
@@ -201,8 +208,8 @@ class objearth():
 
     def percentcloud(self,Dataset):
         '''
-        :param Dataset: Xarray dataset pixel_qa bands
-        :return : percent of the cloud in the image
+        :param Dataset : Xarray dataset pixel_qa bands
+        :return        : percent of the cloud in the image
         '''
         self.Dataset = Dataset
         FashCloud = [352,480,944]
@@ -220,8 +227,8 @@ class objearth():
     def NDVI(self,DataArray):
         """
         calc NDVI (Normalized Difference vegetation Index)
-        :param DataArray (Red bands,NIR bands):
-        :return : NDVI array
+        :param DataArray : (Red bands,NIR bands):
+        :return          : NDVI array
         """
         self.DataArray = DataArray
         red = xarray.where(self.DataArray.red==-9999,numpy.nan,self.DataArray.red)
@@ -240,8 +247,8 @@ class objearth():
     def EVI(self,DataArray):
         """
         calc EVI (Enhanced Vegetation Index)
-        :param DataArray (RED bands,BLUE bands,NIR bands):
-        :return : EVI array
+        :param DataArray : (RED bands,BLUE bands,NIR bands):
+        :return          : EVI array
         """
         self.DataArray = DataArray
         red = xarray.where(self.DataArray.red==-9999,numpy.nan,self.DataArray.red)
@@ -262,8 +269,8 @@ class objearth():
     def NDMI(self,DataArray):
         """
         calc NDMI (Normalized Difference Moisture Index)
-        :param DataArray (SWIR-1 bands,NIR bands):
-        :return : NDMI array
+        :param DataArray : (SWIR-1 bands,NIR bands):
+        :return          : NDMI array
         """
         self.DataArray = DataArray
         swir = xarray.where(self.DataArray.swir1==-9999,numpy.nan,self.DataArray.swir1)
@@ -282,8 +289,8 @@ class objearth():
     def BSI(self,DataArray):
         """
         calc BSI (Bare Soil Index)
-        :param DataArray (GREEN bands,NIR bands):
-        :return : BSI array
+        :param DataArray : (GREEN bands,NIR bands):
+        :return          : BSI array
         """
         self.DataArray = DataArray
         green = xarray.where(self.DataArray.green==-9999,numpy.nan,self.DataArray.green)
@@ -302,8 +309,8 @@ class objearth():
     def NDWI(self,DataArray):
         """
         calc NDWI (Normalized Difference Water Index)
-        :param DataArray (SWIR bands,NIR bands):
-        :return : NDMI array
+        :param DataArray : (SWIR bands,NIR bands):
+        :return          : NDMI array
         """
         self.DataArray = DataArray
         swir = xarray.where(self.DataArray.swir1==-9999,numpy.nan,self.DataArray.swir1)
@@ -322,8 +329,8 @@ class objearth():
     def NMDI(self,DataArray):
         """
         calc NMDI (Normalized Multi-Band Drought Index)
-        :param DataArray (SWIR1 bands,SWIR2 bands,NIR bands):
-        :return : NMDI array
+        :param DataArray : (SWIR1 bands,SWIR2 bands,NIR bands):
+        :return          : NMDI array
         """
         self.DataArray = DataArray
         swir1 = xarray.where(self.DataArray.swir1==-9999,numpy.nan,self.DataArray.swir1)
@@ -343,8 +350,8 @@ class objearth():
     def NDDI(self,DataArray):
         """
         calc NDDI (Normalized Difference Drought Index)
-        :param DataArray (RED bands,NIR bands,SWIR bands):
-        :return : NDDI array
+        :param DataArray : (RED bands,NIR bands,SWIR bands):
+        :return          : NDDI array
         """
         self.DataArray = DataArray
         red = xarray.where(self.DataArray.red==-9999,numpy.nan,self.DataArray.red)
@@ -366,11 +373,11 @@ class objearth():
     def genimg(size=[2,2],range=[-1,1],nan=0,inf=0):
         """
         Generate 1D images with random values.
-        :param size : size of image
+        :param size  : size of image
         :param range : Range of value
-        :param nan : Number of NaN
-        :param inf : Number of Inf
-        :return : 1D array image
+        :param nan   : Number of NaN
+        :param inf   : Number of Inf
+        :return      : 1D array image
         """
         data = numpy.random.uniform(range[0],range[1],[size[0],size[1]])
         index_nan = numpy.random.choice(data.size,nan,replace=1)
@@ -383,8 +390,8 @@ class objearth():
     def bandopen(target):
         """
         Open TIFF image
-        :param target: path of image
-        :return : ndarray
+        :param target : path of image
+        :return       : ndarray
         """
         return gdal.Open(target).ReadAsArray()
 
@@ -392,9 +399,9 @@ class objearth():
     # def geo_save(array,filename,geo_transform = (0.0,1.0,0.0,0.0,0.0,1.0),projection='',dtype=gdal.GDT_Byte):
     #     """
     #     Save array to image
-    #     :param array : ndarray
+    #     :param array    : ndarray
     #     :param filename : filename
-    #     :return TIFF image 
+    #     :return         : TIFF image 
     #     """
     #     filename = Path(os.getcwd()).joinpath(filename+'.tif').as_posix()
     #     cols = array.shape[1]
@@ -413,8 +420,8 @@ class objearth():
     def gengaussian(x_size,y_size):
         """
         Create gaussian function array
-        :param x_size:
-        :param y_size:
+        :param x_size : number
+        :param y_size : number
         :return: gaussian ndarray
         """
         x, y = numpy.meshgrid(numpy.linspace(-1,1,x_size), numpy.linspace(-1,1,y_size))
@@ -427,7 +434,7 @@ class objearth():
     def bluesea():
         """
         Bluesea colormap used for waterqualtiy.
-        :return: colormap.
+        :return : colormap.
         """
         RGB6 = (0.1       , 0.1       , 0.1       )     #RGB(252,252,252)
         RGB5 = (0.        , 0.31372549, 0.45098039)     #RGB(114,199,236)
@@ -469,7 +476,7 @@ class objearth():
     def leafwood():
         """
         Leafwood colormap used for NDVI.
-        :return: colormap.
+        :return : colormap.
         """
         #https://mycolor.space/gradient?ori=to+right+top&hex=%2385A938&hex2=%233C770E&sub=1
         #https://imagecolorpicker.com/en
@@ -567,7 +574,7 @@ class objearth():
     def sweetrose():
         """
         Sweetrose colormap used for NDVI.
-        :return: colormap.
+        :return : colormap.
         """
         RGB1  = (1.        , 1.        , 1.        )    # rgba(254,254,254,255)
         RGB2  = (0.98823529, 0.88627451, 0.98823529)    # rgba(254,225,253,255)
@@ -718,11 +725,11 @@ class water:
             """
             Calc the normalized difference of given arrays (img1 - img2)/(img1 + img2).
             Updates the mask if any invalid numbers (ex. np.inf or np.nan) are encountered
-            :param img1: first array
-            :param img2: second array
-            :param mask: initial mask, that will be updated
-            :param compress_cte: amount of index compression. The greater, the more the index will be compressed towards 0
-            :return: nd array filled with -9999 in the mask and the mask itself
+            :param img1         : first array
+            :param img2         : second array
+            :param mask         : initial mask, that will be updated
+            :param compress_cte : amount of index compression. The greater, the more the index will be compressed towards 0
+            :return             : nd array filled with -9999 in the mask and the mask itself
             """
             # create a minimum array
             min_values = np.where(img1 < img2, img1, img2)
@@ -777,7 +784,7 @@ class water:
             """
             Convert self.bands to a column type matrix where each band is a column
             It follows the order of the keys ordered
-            :return: column type matrix
+            :return : column type matrix
             """
             data = None
             for key in sorted(bands.keys()):
@@ -797,11 +804,11 @@ class water:
         def get_train_test_split(data,train_size,min_train_size,max_train_size):
             """
             Split the provided data in train-test bunches
-            :param min_train_size: minimum data quantity for train set
-            :param max_train_size: maximum data quantity for train set
-            :param train_size: percentage of the data to be used as train dataset
-            :param data: data to be split
-            :return: train and test datasets
+            :param min_train_size : minimum data quantity for train set
+            :param max_train_size : maximum data quantity for train set
+            :param train_size     : percentage of the data to be used as train dataset
+            :param data           : data to be split
+            :return               : train and test datasets
             """
             dataset_size = data.shape[0]
 
@@ -819,9 +826,9 @@ class water:
         def split_data_by_bands(bands,data, selected_keys):
             """
             Gets data in column format (each band is a column) and returns only the desired bands
-            :param data: data in column format
-            :param selected_keys: bands keys to be extracted
-            :return: data in column format only with the selected bands
+            :param data          : data in column format
+            :param selected_keys : bands keys to be extracted
+            :return              : data in column format only with the selected bands
             """
             bands_index = []
             bands_keys = list(sorted(bands.keys()))
@@ -834,8 +841,8 @@ class water:
         def find_best_k(self,data):
             """
             Find the best number of clusters according to an metrics.
-            :param data: data to be tested
-            :return: number of clusters
+            :param data : data to be tested
+            :return     : number of clusters
             """
             # print('min_k :',self.min_k)
             # print('max_k :',self.max_k)
@@ -882,8 +889,8 @@ class water:
         def apply_cluster(data,best_k):
             """
             Apply the cluster algorithm to the data. Number of cluster is in self.best_k
-            :param data: data to be clustered
-            :return: Vector with the labels
+            :param data  : data to be clustered
+            :return      : Vector with the labels
             """
             clustering_method = 'agglomerative'
             if clustering_method == 'kmeans':
@@ -902,9 +909,9 @@ class water:
             """
             Calculate parameters for each encountered cluster.
             Mean, Variance, Std-dev
-            :param data: Clustered data
-            :param clusters_labels: Labels for the data
-            :return: List with cluster statistics
+            :param data            : Clustered data
+            :param clusters_labels : Labels for the data
+            :return                : List with cluster statistics
             """
             clusters_params = []
             for label_i in range(best_k):
@@ -927,11 +934,11 @@ class water:
         def detect_cluster(bands,clusters_params, param, logic, band1, band2=None):
             """
             Detects a cluster according to a specific metrics
-            :param param: Which parameter to search (mean, std-dev, variance,  ...)
-            :param logic: Max or Min
-            :param band1: The band related to the parameter
-            :param band2:
-            :return: Cluster object that satisfies the logic
+            :param param : Which parameter to search (mean, std-dev, variance,  ...)
+            :param logic : Max or Min
+            :param band1 : The band related to the parameter
+            :param band2 :
+            :return      : Cluster object that satisfies the logic
             """
             # get the bands available in the columns
             available_bands = sorted(bands.keys())
@@ -1001,10 +1008,10 @@ class water:
         def apply_naive_bayes(data, clusters_labels, clusters_data):
             """
             Apply Naive Bayes classifier to classify data
-            :param data: new data to be classified
-            :param clusters_labels: labels for the reference data
-            :param clusters_data: reference data
-            :return: labels for the new data
+            :param data            : new data to be classified
+            :param clusters_labels : labels for the reference data
+            :param clusters_data   : reference data
+            :return                : labels for the new data
             """
             # train a NB classifier with the data and labels provided
             model = GaussianNB()
@@ -1021,10 +1028,10 @@ class water:
         def supervised_classification(self,data, train_data, clusters_labels):
             """
             Applies a machine learning supervised classification
-            :param data: new data to be classified
-            :param train_data: reference data
-            :param clusters_labels: labels for the reference data
-            :return: labels for the new data
+            :param data            : new data to be classified
+            :param train_data      : reference data
+            :param clusters_labels : labels for the reference data
+            :return                : labels for the new data
             """
             if self.classifier == 'SVM':
                 clusters_labels = apply_svm(data, clusters_labels, train_data)
@@ -1042,8 +1049,8 @@ class water:
         def create_matrice_cluster(indices_array,bands,clusters_labels,water_cluster,best_k):
             """
             Recreates the matrix with the original shape with the cluster labels for each pixel
-            :param indices_array: position of the clustered pixels in the matrix
-            :return: clustered image (0-no data, 1-water, 2, 3, ... - other)
+            :param indices_array : position of the clustered pixels in the matrix
+            :return              : clustered image (0-no data, 1-water, 2, 3, ... - other)
             """
             # create an empty matrix
             matrice_cluster = np.zeros_like(list(bands.values())[0]).astype('int8')
@@ -1074,7 +1081,7 @@ class water:
         def waterdetect(self):
             """
             waterdetection
-            :return: watermask
+            :return : watermask
             """
             ## wd.DWImageClustering
             # get the first band as reference of size
@@ -1187,11 +1194,11 @@ class water:
         def apply_mask(array, mask, no_data_value=-9999, clear_nan=True):
             """
             Update mask
-            :param array: array of data
-            :param mask: mask
-            :param no_data_value: 
-            :param clear_nan:
-            :return: Updated mask
+            :param array         : array of data
+            :param mask          : mask
+            :param no_data_value : 
+            :param clear_nan     :
+            :return              : Updated mask
             """
             if clear_nan:
                 mask |= np.isnan(array) | np.isinf(array)
@@ -1201,11 +1208,11 @@ class water:
         def calc_param_limits(parameter, no_data_value=-9999,min_param_value=5,max_param_value = 20):
             """
             calulation min & max value by using percentile
-            :param parameter: ndarray data
-            :param no_data_value: no_data_value
-            :param min_param_value: min_value
-            :param max_param_value: max_value
-            :return: min_value,max_value
+            :param parameter       : ndarray data
+            :param no_data_value   : no_data_value
+            :param min_param_value : min_value
+            :param max_param_value : max_value
+            :return                : min_value,max_value
             """
             valid = parameter[parameter != no_data_value]
             min_value = np.percentile(valid, 1) if min_param_value is None else min_param_value
@@ -1219,14 +1226,14 @@ class water:
             """
             Convert a greyscale n-dimensional matrix into a rgb matrix, adding 3 dimensions to it for R, G, and B
             The colors will be mixed
-            :param max_value: Maximum value for the color ramp, if None, we consider max(grey)
-            :param min_value: Minimum value for the color ramp, if None, we consider min(grey)
-            :param grey_array: greyscale vector/matrix
-            :param color1: Color for the minimum value
-            :param color2: Color for the mid value
-            :param color3: Color for the maximum value
-            :param limits: Final boundary limits for the RGB values
-            :return: Colored vector/matrix
+            :param max_value  : Maximum value for the color ramp, if None, we consider max(grey)
+            :param min_value  : Minimum value for the color ramp, if None, we consider min(grey)
+            :param grey_array : greyscale vector/matrix
+            :param color1     : Color for the minimum value
+            :param color2     : Color for the mid value
+            :param color3     : Color for the maximum value
+            :param limits     : Final boundary limits for the RGB values
+            :return           : Colored vector/matrix
             """
 
             cm = plt.get_cmap(colormap)
@@ -1248,19 +1255,19 @@ class water:
             """
             Burn in a mask or a specific parameter into an RGB image for visualization purposes.
             The burn_in_array will be copied where values are different from no_data_value.
-            :param uniform_distribution: convert the input values in a uniform histogram
-            :param colormap: matplotlib colormap (string) to create the RGB ramp
-            :param max_value: maximum value
-            :param min_value: minimum value
-            :param red: Original red band
-            :param green: Original green band
-            :param blue: Original blue band
-            :param burn_in_array: Values to be burnt in
-            :param no_data_value: Value to ne unconsidered
-            :param color: Tuple of color (R, G, B) to be used in the burn in
-            :param fade: Fade the RGB bands to emphasize the copied values
-            :param transp: Transparency to use in the mask (0=opaque 1=completely transparent)
-            :return: RGB image bands
+            :param uniform_distribution : convert the input values in a uniform histogram
+            :param colormap             : matplotlib colormap (string) to create the RGB ramp
+            :param max_value            : maximum value
+            :param min_value            : minimum value
+            :param red                  : Original red band
+            :param green                : Original green band
+            :param blue                 : Original blue band
+            :param burn_in_array        : Values to be burnt in
+            :param no_data_value        : Value to ne unconsidered
+            :param color                : Tuple of color (R, G, B) to be used in the burn in
+            :param fade                 : Fade the RGB bands to emphasize the copied values
+            :param transp               : Transparency to use in the mask (0=opaque 1=completely transparent)
+            :return                     : RGB image bands
             """
             if color:
                 new_red = np.where(burn_in_array == valid_value, color[0] * (1 - transp) + red * (transp), red * fade)
@@ -1302,8 +1309,8 @@ class water:
             """
             Turbidity and Suspended Particulate Matter (SPM) fuction
             SPM algorithm proposed by Nechad et al. (2010) https://www.sciencedirect.com/science/article/pii/S0034425714003654
-            :param Red: Red band values
-            :return: float
+            :param Red : Red band values
+            :return    : float
             """
             a = 493.65
             b = 1.16
@@ -1316,14 +1323,14 @@ class water:
         def waterquality(self,watermask,waterquality_function=None,range=None,colormap=True,bright=5,title='',label=''):
             """
             waterquality (Main fn)
-            :param watermask: water mask area that want to burn
-            :param waterquality_function: operate function
-            :param range: range of value
-            :param colormap: colormap that show 
-            :param bright: bright of saltellite image
-            :param title: title of colorbar
-            :param label: label of colorbar
-            :return: R,G,B array
+            :param watermask             : water mask area that want to burn
+            :param waterquality_function : operate function
+            :param range                 : range of value
+            :param colormap              : colormap that show 
+            :param bright                : bright of saltellite image
+            :param title                 : title of colorbar
+            :param label                 : label of colorbar
+            :return                      : R,G,B array
             """
             # Watermask
             self.watermask = watermask
